
/**
 * Require the given path.
 *
 * @param {String} path
 * @return {Object} exports
 * @api public
 */

function require(path, parent, orig) {
  var resolved = require.resolve(path);

  // lookup failed
  if (null == resolved) {
    orig = orig || path;
    parent = parent || 'root';
    var err = new Error('Failed to require "' + orig + '" from "' + parent + '"');
    err.path = orig;
    err.parent = parent;
    err.require = true;
    throw err;
  }

  var module = require.modules[resolved];

  // perform real require()
  // by invoking the module's
  // registered function
  if (!module.exports) {
    module.exports = {};
    module.client = module.component = true;
    module.call(this, module.exports, require.relative(resolved), module);
  }

  return module.exports;
}

/**
 * Registered modules.
 */

require.modules = {};

/**
 * Registered aliases.
 */

require.aliases = {};

/**
 * Resolve `path`.
 *
 * Lookup:
 *
 *   - PATH/index.js
 *   - PATH.js
 *   - PATH
 *
 * @param {String} path
 * @return {String} path or null
 * @api private
 */

require.resolve = function(path) {
  if (path.charAt(0) === '/') path = path.slice(1);

  var paths = [
    path,
    path + '.js',
    path + '.json',
    path + '/index.js',
    path + '/index.json'
  ];

  for (var i = 0; i < paths.length; i++) {
    var path = paths[i];
    if (require.modules.hasOwnProperty(path)) return path;
    if (require.aliases.hasOwnProperty(path)) return require.aliases[path];
  }
};

/**
 * Normalize `path` relative to the current path.
 *
 * @param {String} curr
 * @param {String} path
 * @return {String}
 * @api private
 */

require.normalize = function(curr, path) {
  var segs = [];

  if ('.' != path.charAt(0)) return path;

  curr = curr.split('/');
  path = path.split('/');

  for (var i = 0; i < path.length; ++i) {
    if ('..' == path[i]) {
      curr.pop();
    } else if ('.' != path[i] && '' != path[i]) {
      segs.push(path[i]);
    }
  }

  return curr.concat(segs).join('/');
};

/**
 * Register module at `path` with callback `definition`.
 *
 * @param {String} path
 * @param {Function} definition
 * @api private
 */

require.register = function(path, definition) {
  require.modules[path] = definition;
};

/**
 * Alias a module definition.
 *
 * @param {String} from
 * @param {String} to
 * @api private
 */

require.alias = function(from, to) {
  if (!require.modules.hasOwnProperty(from)) {
    throw new Error('Failed to alias "' + from + '", it does not exist');
  }
  require.aliases[to] = from;
};

/**
 * Return a require function relative to the `parent` path.
 *
 * @param {String} parent
 * @return {Function}
 * @api private
 */

require.relative = function(parent) {
  var p = require.normalize(parent, '..');

  /**
   * lastIndexOf helper.
   */

  function lastIndexOf(arr, obj) {
    var i = arr.length;
    while (i--) {
      if (arr[i] === obj) return i;
    }
    return -1;
  }

  /**
   * The relative require() itself.
   */

  function localRequire(path) {
    var resolved = localRequire.resolve(path);
    return require(resolved, parent, path);
  }

  /**
   * Resolve relative to the parent.
   */

  localRequire.resolve = function(path) {
    var c = path.charAt(0);
    if ('/' == c) return path.slice(1);
    if ('.' == c) return require.normalize(p, path);

    // resolve deps by returning
    // the dep in the nearest "deps"
    // directory
    var segs = parent.split('/');
    var i = lastIndexOf(segs, 'deps') + 1;
    if (!i) i = 0;
    path = segs.slice(0, i + 1).join('/') + '/deps/' + path;
    return path;
  };

  /**
   * Check if module is defined at `path`.
   */

  localRequire.exists = function(path) {
    return require.modules.hasOwnProperty(localRequire.resolve(path));
  };

  return localRequire;
};
require.register("component-jquery/index.js", Function("exports, require, module",
"//@ sourceURL=component-jquery/index.js"
));
require.register("visionmedia-debug/index.js", Function("exports, require, module",
"//@ sourceURL=visionmedia-debug/index.js"
));
require.register("visionmedia-debug/debug.js", Function("exports, require, module",
"//@ sourceURL=visionmedia-debug/debug.js"
));
require.register("component-emitter/index.js", Function("exports, require, module",
"//@ sourceURL=component-emitter/index.js"
));
require.register("component-inherit/index.js", Function("exports, require, module",
"//@ sourceURL=component-inherit/index.js"
));
require.register("pinkTurtle-newslider/index.js", Function("exports, require, module",
"//@ sourceURL=pinkTurtle-newslider/index.js"
));
require.register("main/index.js", Function("exports, require, module",
"/**\n *  * Module dependencies\n *   */\n\nvar o = jQuery = require('jquery');\n\nvar debug = require('debug')('smr');\n\no(document).ready(function() {\n\n  // Main slider\n  if (o('.slides').length) {\n    debug('Rendering main slider');\n\n    var NewSlider = require('newslider');\n    var firstslide = o('a.firstslide');\n    var nextslide = o('a.nextslide');\n    var prevslide = o('a.prevslide');\n    var lastslide = o('a.lastslide');\n\n    var mySlider = new NewSlider('.slides');\n\n    lastslide.click(function(){\n      mySlider.last();\n    });\n\n    firstslide.click(function(){\n      mySlider.first();\n    });\n\n    nextslide.click(function(){\n      mySlider.next();\n    });\n\n    prevslide.click(function(){\n      mySlider.prev();\n    });\n\n    mySlider.slides.eq(0).removeClass(\"currentslide\");\n    mySlider.goto(1);\n\n    var slideTimer = window.setInterval(function(){\n      if(mySlider.current >= (mySlider.slides.length - 2)) {\n        mySlider.current = 0;\n      }\n      mySlider.slides.eq(mySlider.current - 2).removeClass(\"currentslide\");\n      mySlider.next();\n    }, 7000);\n  }\n\n  // conent slider\n  if (o('.clientes-individual .content-slider').length) {\n\n\n    (function(){\n      var delay = 7000;\n      var slideTimer;\n      var NewSlider = require('newslider');\n\n      var contentSlider = new NewSlider(o('.clientes-individual .content-slider'));\n      slider_restart();\n\n      var sliderContainer = o('.slider-navigator');\n\n      sliderContainer.on('click', 'div', function() {\n        var action = o(this).attr('class').substr(3);\n        repro[action]();\n      });\n\n      /**\n       * slider player\n       */\n\n      var repro = {\n        play: function() {\n          contentSlider.next();\n          slider_restart();\n        },\n        stop: function(){\n          slider_stop();\n        },\n        left: function(){\n          contentSlider.prev();\n        },\n        right: function(){\n          contentSlider.next();\n        }\n      };\n\n      /**\n       * Stop the slider\n       */\n\n      function slider_stop(){\n        clearInterval(slideTimer);\n      }\n\n      /**\n       * Restart the slider\n       */\n\n      function slider_restart(){\n        if (slideTimer) {\n          clearInterval(slideTimer);\n        };\n\n        // run slider animation\n        slideTimer = window.setInterval(function(){\n          contentSlider.next();\n        }, delay);\n      }\n    })();\n  }\n\n  // Servicios slider\n  if (o('.servicios:first-child .content-slider').length) {\n    (function(){\n      var delay = 7000;\n      var slideTimer;\n      var NewSlider = require('newslider');\n\n      var contentSlider = new NewSlider(o('.servicios:first-child .content-slider'));\n      slider_restart();\n\n      var sliderContainer = o('.slider-navigator');\n\n      sliderContainer.on('click', 'div', function() {\n        var action = o(this).attr('class').substr(3);\n        repro[action]();\n      });\n\n      /**\n       * slider player\n       */\n\n      var repro = {\n        play: function() {\n          contentSlider.next();\n          slider_restart();\n        },\n        stop: function(){\n          slider_stop();\n        },\n        left: function(){\n          contentSlider.prev();\n        },\n        right: function(){\n          contentSlider.next();\n        }\n      };\n\n      /**\n       * Stop the slider\n       */\n\n      function slider_stop(){\n        clearInterval(slideTimer);\n      }\n\n      /**\n       * Restart the slider\n       */\n\n      function slider_restart(){\n        if (slideTimer) {\n          clearInterval(slideTimer);\n        };\n\n        // run slider animation\n        slideTimer = window.setInterval(function(){\n          contentSlider.next();\n        }, delay);\n      }\n    })();\n  }\n\n    // seccion servicios\n    // manejo de divs y \n    // de slider\n\n    o(\".descripciones .servicios\").click(function() {\n      if (o(this).find('.contenido-servicios').css('display')=='none') {\n        o('.descripciones .servicios .contenido-servicios').slideUp( \"slow\" );\n        o('.descripciones .servicios .contenido-servicios').css( 'opacity', '0' );\n        o(this).find('.contenido-servicios').slideDown( \"slow\" );\n        o(this).find('.contenido-servicios').css( 'opacity', '1' );\n        contentSlider = null;\n        clearInterval(slideTimer);\n\n        if (o(this).find('.content-slider').length) {\n          var a = o(this).find('.content-slider');\n          console.log(a);\n          (function(){\n            var delay = 7000;\n            var slideTimer;\n            var NewSlider = require('newslider');\n\n            var contentSlider = new NewSlider(a);\n            slider_restart();\n\n            var sliderContainer = o('.slider-navigator');\n\n            sliderContainer.on('click', 'div', function() {\n              var action = o(this).attr('class').substr(3);\n              repro[action]();\n            });\n\n            /**\n             * slider player\n             */\n\n            var repro = {\n              play: function() {\n                contentSlider.next();\n                slider_restart();\n              },\n              stop: function(){\n                slider_stop();\n              },\n              left: function(){\n                contentSlider.prev();\n              },\n              right: function(){\n                contentSlider.next();\n              }\n            };\n\n            /**\n             * Stop the slider\n             */\n\n            function slider_stop(){\n              clearInterval(slideTimer);\n            }\n\n            /**\n             * Restart the slider\n             */\n\n            function slider_restart(){\n              if (slideTimer) {\n                clearInterval(slideTimer);\n              };\n\n              // run slider animation\n              slideTimer = window.setInterval(function(){\n                contentSlider.next();\n              }, delay);\n            }\n          })();\n\n        }\n      }\n    });\n\n});\n//@ sourceURL=main/index.js"
));
require.alias("component-jquery/index.js", "main/deps/jquery/index.js");
require.alias("component-jquery/index.js", "jquery/index.js");

require.alias("visionmedia-debug/index.js", "main/deps/debug/index.js");
require.alias("visionmedia-debug/debug.js", "main/deps/debug/debug.js");
require.alias("visionmedia-debug/index.js", "debug/index.js");

require.alias("pinkTurtle-newslider/index.js", "main/deps/newslider/index.js");
require.alias("pinkTurtle-newslider/index.js", "newslider/index.js");
require.alias("component-emitter/index.js", "pinkTurtle-newslider/deps/emitter/index.js");

require.alias("component-jquery/index.js", "pinkTurtle-newslider/deps/jquery/index.js");

require.alias("component-inherit/index.js", "pinkTurtle-newslider/deps/inherit/index.js");

require.alias("visionmedia-debug/index.js", "pinkTurtle-newslider/deps/debug/index.js");
require.alias("visionmedia-debug/debug.js", "pinkTurtle-newslider/deps/debug/debug.js");

