
/**
 * Require the given path.
 *
 * @param {String} path
 * @return {Object} exports
 * @api public
 */

function require(path, parent, orig) {
  var resolved = require.resolve(path);

  // lookup failed
  if (null == resolved) {
    orig = orig || path;
    parent = parent || 'root';
    var err = new Error('Failed to require "' + orig + '" from "' + parent + '"');
    err.path = orig;
    err.parent = parent;
    err.require = true;
    throw err;
  }

  var module = require.modules[resolved];

  // perform real require()
  // by invoking the module's
  // registered function
  if (!module.exports) {
    module.exports = {};
    module.client = module.component = true;
    module.call(this, module.exports, require.relative(resolved), module);
  }

  return module.exports;
}

/**
 * Registered modules.
 */

require.modules = {};

/**
 * Registered aliases.
 */

require.aliases = {};

/**
 * Resolve `path`.
 *
 * Lookup:
 *
 *   - PATH/index.js
 *   - PATH.js
 *   - PATH
 *
 * @param {String} path
 * @return {String} path or null
 * @api private
 */

require.resolve = function(path) {
  if (path.charAt(0) === '/') path = path.slice(1);

  var paths = [
    path,
    path + '.js',
    path + '.json',
    path + '/index.js',
    path + '/index.json'
  ];

  for (var i = 0; i < paths.length; i++) {
    var path = paths[i];
    if (require.modules.hasOwnProperty(path)) return path;
    if (require.aliases.hasOwnProperty(path)) return require.aliases[path];
  }
};

/**
 * Normalize `path` relative to the current path.
 *
 * @param {String} curr
 * @param {String} path
 * @return {String}
 * @api private
 */

require.normalize = function(curr, path) {
  var segs = [];

  if ('.' != path.charAt(0)) return path;

  curr = curr.split('/');
  path = path.split('/');

  for (var i = 0; i < path.length; ++i) {
    if ('..' == path[i]) {
      curr.pop();
    } else if ('.' != path[i] && '' != path[i]) {
      segs.push(path[i]);
    }
  }

  return curr.concat(segs).join('/');
};

/**
 * Register module at `path` with callback `definition`.
 *
 * @param {String} path
 * @param {Function} definition
 * @api private
 */

require.register = function(path, definition) {
  require.modules[path] = definition;
};

/**
 * Alias a module definition.
 *
 * @param {String} from
 * @param {String} to
 * @api private
 */

require.alias = function(from, to) {
  if (!require.modules.hasOwnProperty(from)) {
    throw new Error('Failed to alias "' + from + '", it does not exist');
  }
  require.aliases[to] = from;
};

/**
 * Return a require function relative to the `parent` path.
 *
 * @param {String} parent
 * @return {Function}
 * @api private
 */

require.relative = function(parent) {
  var p = require.normalize(parent, '..');

  /**
   * lastIndexOf helper.
   */

  function lastIndexOf(arr, obj) {
    var i = arr.length;
    while (i--) {
      if (arr[i] === obj) return i;
    }
    return -1;
  }

  /**
   * The relative require() itself.
   */

  function localRequire(path) {
    var resolved = localRequire.resolve(path);
    return require(resolved, parent, path);
  }

  /**
   * Resolve relative to the parent.
   */

  localRequire.resolve = function(path) {
    var c = path.charAt(0);
    if ('/' == c) return path.slice(1);
    if ('.' == c) return require.normalize(p, path);

    // resolve deps by returning
    // the dep in the nearest "deps"
    // directory
    var segs = parent.split('/');
    var i = lastIndexOf(segs, 'deps') + 1;
    if (!i) i = 0;
    path = segs.slice(0, i + 1).join('/') + '/deps/' + path;
    return path;
  };

  /**
   * Check if module is defined at `path`.
   */

  localRequire.exists = function(path) {
    return require.modules.hasOwnProperty(localRequire.resolve(path));
  };

  return localRequire;
};
require.register("component-jquery/index.js", Function("exports, require, module",
"//@ sourceURL=component-jquery/index.js"
));
require.register("visionmedia-debug/index.js", Function("exports, require, module",
"//@ sourceURL=visionmedia-debug/index.js"
));
require.register("visionmedia-debug/debug.js", Function("exports, require, module",
"//@ sourceURL=visionmedia-debug/debug.js"
));
require.register("component-emitter/index.js", Function("exports, require, module",
"//@ sourceURL=component-emitter/index.js"
));
require.register("component-inherit/index.js", Function("exports, require, module",
"//@ sourceURL=component-inherit/index.js"
));
require.register("pinkTurtle-newslider/index.js", Function("exports, require, module",
"//@ sourceURL=pinkTurtle-newslider/index.js"
));
require.register("main/index.js", Function("exports, require, module",
"/**\n *  * Module dependencies\n *   */\n\nvar o = jQuery = require('jquery');\n\nvar debug = require('debug')('smr');\n\no(document).ready(function() {\n\n  // Main slider\n  if (o('.slides').length) {\n    debug('Rendering main slider');\n\n    var NewSlider = require('newslider');\n    var firstslide = o('a.firstslide');\n    var nextslide = o('a.nextslide');\n    var prevslide = o('a.prevslide');\n    var lastslide = o('a.lastslide');\n\n    var mySlider = new NewSlider('.slides');\n\n    lastslide.click(function(){\n      mySlider.last();\n    });\n\n    firstslide.click(function(){\n      mySlider.first();\n    });\n\n    nextslide.click(function(){\n      mySlider.next();\n    });\n\n    prevslide.click(function(){\n      mySlider.prev();\n    });\n\n    mySlider.slides.eq(0).removeClass(\"currentslide\");\n    mySlider.goto(1);\n\n    var slideTimer = window.setInterval(function(){\n      if(mySlider.current >= (mySlider.slides.length - 2)) {\n        mySlider.current = 0;\n      }\n      mySlider.slides.eq(mySlider.current - 2).removeClass(\"currentslide\");\n      mySlider.next();\n    }, 7000);\n  }\n\n  // conent slider\n  if (o('.clientes-individual .content-slider').length) {\n\n\n    (function(){\n      var delay = 7000;\n      var slideTimer;\n      var NewSlider = require('newslider');\n\n      var contentSlider = new NewSlider(o('.clientes-individual .content-slider'));\n      slider_restart();\n\n      var sliderContainer = o('.slider-navigator');\n\n      sliderContainer.on('click', 'div', function() {\n        var action = o(this).attr('class').substr(3);\n        repro[action]();\n      });\n\n      /**\n       * slider player\n       */\n\n      var repro = {\n        play: function() {\n          contentSlider.next();\n          slider_restart();\n        },\n        stop: function(){\n          slider_stop();\n        },\n        left: function(){\n          contentSlider.prev();\n        },\n        right: function(){\n          contentSlider.next();\n        }\n      };\n\n      /**\n       * Stop the slider\n       */\n\n      function slider_stop(){\n        clearInterval(slideTimer);\n      }\n\n      /**\n       * Restart the slider\n       */\n\n      function slider_restart(){\n        if (slideTimer) {\n          clearInterval(slideTimer);\n        };\n\n        // run slider animation\n        slideTimer = window.setInterval(function(){\n          contentSlider.next();\n        }, delay);\n      }\n    })();\n  }\n\n  // Servicios slider\n  if (o('.servicios:first-child .content-slider').length) {\n    (function(){\n      var delay = 7000;\n      var slideTimer;\n      var NewSlider = require('newslider');\n\n      var contentSlider = new NewSlider(o('.servicios:first-child .content-slider'));\n      slider_restart();\n\n      var sliderContainer = o('.slider-navigator');\n\n      sliderContainer.on('click', 'div', function() {\n        var action = o(this).attr('class').substr(3);\n        repro[action]();\n      });\n\n      /**\n       * slider player\n       */\n\n      var repro = {\n        play: function() {\n          contentSlider.next();\n          slider_restart();\n        },\n        stop: function(){\n          slider_stop();\n        },\n        left: function(){\n          contentSlider.prev();\n        },\n        right: function(){\n          contentSlider.next();\n        }\n      };\n\n      /**\n       * Stop the slider\n       */\n\n      function slider_stop(){\n        clearInterval(slideTimer);\n      }\n\n      /**\n       * Restart the slider\n       */\n\n      function slider_restart(){\n        if (slideTimer) {\n          clearInterval(slideTimer);\n        };\n\n        // run slider animation\n        slideTimer = window.setInterval(function(){\n          contentSlider.next();\n        }, delay);\n      }\n    })();\n  }\n\n    // seccion servicios\n    // manejo de divs y \n    // de slider\n\n    o(\".descripciones .servicios\").click(function() {\n      if (o(this).find('.contenido-servicios').css('display')=='none') {\n        o('.descripciones .servicios .contenido-servicios').slideUp( \"slow\" );\n        o('.descripciones .servicios .contenido-servicios').css( 'opacity', '0' );\n        o(this).find('.contenido-servicios').slideDown( \"slow\" );\n        o(this).find('.contenido-servicios').css( 'opacity', '1' );\n        contentSlider = null;\n        clearInterval(slideTimer);\n\n        if (o(this).find('.content-slider').length) {\n          var a = o(this).find('.content-slider');\n          console.log(a);\n          (function(){\n            var delay = 7000;\n            var slideTimer;\n            var NewSlider = require('newslider');\n\n            var contentSlider = new NewSlider(a);\n            slider_restart();\n\n            var sliderContainer = o('.slider-navigator');\n\n            sliderContainer.on('click', 'div', function() {\n              var action = o(this).attr('class').substr(3);\n              repro[action]();\n            });\n\n            /**\n             * slider player\n             */\n\n            var repro = {\n              play: function() {\n                contentSlider.next();\n                slider_restart();\n              },\n              stop: function(){\n                slider_stop();\n              },\n              left: function(){\n                contentSlider.prev();\n              },\n              right: function(){\n                contentSlider.next();\n              }\n            };\n\n            /**\n             * Stop the slider\n             */\n\n            function slider_stop(){\n              clearInterval(slideTimer);\n            }\n\n            /**\n             * Restart the slider\n             */\n\n            function slider_restart(){\n              if (slideTimer) {\n                clearInterval(slideTimer);\n              };\n\n              // run slider animation\n              slideTimer = window.setInterval(function(){\n                contentSlider.next();\n              }, delay);\n            }\n          })();\n\n        }\n      }\n    });\n\n});\n//@ sourceURL=main/index.js"
));
require.register("main/bind.js", Function("exports, require, module",
"\n/**\n * ugly as fuck Function#bind() implementation from MDC\n */\n\nif (!Function.prototype.bind) {\n  Function.prototype.bind = function (oThis) {\n    if (typeof this !== \"function\") {\n      // closest thing possible to the ECMAScript 5 internal IsCallable function\n      throw new TypeError(\"Function.prototype.bind - what is trying to be bound is not callable\");\n    }\n\n    var aArgs = Array.prototype.slice.call(arguments, 1),\n      fToBind = this,\n      fNOP = function () {},\n      fBound = function () {\n        return fToBind.apply(this instanceof fNOP\n          ? this\n          : oThis, aArgs.concat(Array.prototype.slice.call(arguments)));\n        };\n\n    fNOP.prototype = this.prototype;\n    fBound.prototype = new fNOP();\n\n    return fBound;\n  };\n}\n//@ sourceURL=main/bind.js"
));
require.register("main/map.js", Function("exports, require, module",
"// Production steps of ECMA-262, Edition 5, 15.4.4.19\n// Reference: http://es5.github.com/#x15.4.4.19\nif (!Array.prototype.map) {\n  Array.prototype.map = function(callback, thisArg) {\n \n    var T, A, k;\n \n    if (this == null) {\n      throw new TypeError(\" this is null or not defined\");\n    }\n \n    // 1. Let O be the result of calling ToObject passing the |this| value as the argument.\n    var O = Object(this);\n \n    // 2. Let lenValue be the result of calling the Get internal method of O with the argument \"length\".\n    // 3. Let len be ToUint32(lenValue).\n    var len = O.length >>> 0;\n \n    // 4. If IsCallable(callback) is false, throw a TypeError exception.\n    // See: http://es5.github.com/#x9.11\n    if (typeof callback !== \"function\") {\n      throw new TypeError(callback + \" is not a function\");\n    }\n \n    // 5. If thisArg was supplied, let T be thisArg; else let T be undefined.\n    if (thisArg) {\n      T = thisArg;\n    }\n \n    // 6. Let A be a new array created as if by the expression new Array(len) where Array is\n    // the standard built-in constructor with that name and len is the value of len.\n    A = new Array(len);\n \n    // 7. Let k be 0\n    k = 0;\n \n    // 8. Repeat, while k < len\n    while(k < len) {\n \n      var kValue, mappedValue;\n \n      // a. Let Pk be ToString(k).\n      //   This is implicit for LHS operands of the in operator\n      // b. Let kPresent be the result of calling the HasProperty internal method of O with argument Pk.\n      //   This step can be combined with c\n      // c. If kPresent is true, then\n      if (k in O) {\n \n        // i. Let kValue be the result of calling the Get internal method of O with argument Pk.\n        kValue = O[ k ];\n \n        // ii. Let mappedValue be the result of calling the Call internal method of callback\n        // with T as the this value and argument list containing kValue, k, and O.\n        mappedValue = callback.call(T, kValue, k, O);\n \n        // iii. Call the DefineOwnProperty internal method of A with arguments\n        /// Pk, Property Descriptor {Value: mappedValue, : true, Enumerable: true, Configurable: true},\n        // and false.\n \n        // In browsers that support Object.defineProperty, use the following:\n        // Object.defineProperty(A, Pk, { value: mappedValue, writable: true, enumerable: true, configurable: true });\n \n        // For best browser support, use the following:\n        A[ k ] = mappedValue;\n      }\n      // d. Increase k by 1.\n      k++;\n    }\n \n    // 9. return A\n    return A;\n  };      \n}\n//@ sourceURL=main/map.js"
));
require.register("main/history.iegte8.js", Function("exports, require, module",
"/*\n * History API JavaScript Library v4.0.5\n *\n * Support: IE8+, FF3+, Opera 9+, Safari, Chrome and other\n *\n * Copyright 2011-2013, Dmitrii Pakhtinov ( spb.piksel@gmail.com )\n *\n * http://spb-piksel.ru/\n *\n * Dual licensed under the MIT and GPL licenses:\n *   http://www.opensource.org/licenses/mit-license.php\n *   http://www.gnu.org/licenses/gpl.html\n *\n * Update: 20.08.13 21:16\n */\n(function(window) {\n    // Prevent the code from running if there is no window.history object\n    if (!window.history) return;\n    // symlink to document\n    var document = window.document;\n    // HTML element\n    var documentElement = document.documentElement;\n    // symlink to sessionStorage\n    var sessionStorage = null;\n    // symlink to constructor of Object\n    var Object = window['Object'];\n    // symlink to JSON Object\n    var JSON = window['JSON'];\n    // symlink to instance object of 'Location'\n    var windowLocation = window.location;\n    // symlink to instance object of 'History'\n    var windowHistory = window.history;\n    // new instance of 'History'. The default is a reference to the original object instance\n    var historyObject = windowHistory;\n    // symlink to method 'history.pushState'\n    var historyPushState = windowHistory.pushState;\n    // symlink to method 'history.replaceState'\n    var historyReplaceState = windowHistory.replaceState;\n    // if the browser supports HTML5-History-API\n    var isSupportHistoryAPI = !!historyPushState;\n    // verifies the presence of an object 'state' in interface 'History'\n    var isSupportStateObjectInHistory = 'state' in windowHistory;\n    // symlink to method 'Object.defineProperty'\n    var defineProperty = Object.defineProperty;\n    // new instance of 'Location', for IE8 will use the element HTMLAnchorElement, instead of pure object\n    var locationObject = redefineProperty({}, 't') ? {} : document.createElement('a');\n    // prefix for the names of events\n    var eventNamePrefix = '';\n    // String that will contain the name of the method\n    var addEventListenerName = window.addEventListener ? 'addEventListener' : (eventNamePrefix = 'on') && 'attachEvent';\n    // String that will contain the name of the method\n    var removeEventListenerName = window.removeEventListener ? 'removeEventListener' : 'detachEvent';\n    // String that will contain the name of the method\n    var dispatchEventName = window.dispatchEvent ? 'dispatchEvent' : 'fireEvent';\n    // reference native methods for the events\n    var addEvent = window[addEventListenerName];\n    var removeEvent = window[removeEventListenerName];\n    var dispatch = window[dispatchEventName];\n    // default settings\n    var settings = {\"basepath\": '/', \"redirect\": 0, \"type\": '/'};\n    // key for the sessionStorage\n    var sessionStorageKey = '__historyAPI__';\n    // Anchor Element for parseURL function\n    var anchorElement = document.createElement('a');\n    // last URL before change to new URL\n    var lastURL = windowLocation.href;\n    // Control URL, need to fix the bug in Opera\n    var checkUrlForPopState = '';\n    // trigger event 'onpopstate' on page load\n    var isFireInitialState = false;\n    // store a list of 'state' objects in the current session\n    var stateStorage = {};\n    // in this object will be stored custom handlers\n    var eventsList = {};\n\n    /**\n     * Properties that will be replaced in the global\n     * object 'window', to prevent conflicts\n     *\n     * @type {Object}\n     */\n    var eventsDescriptors = {\n        \"onhashchange\": null,\n        \"onpopstate\": null\n    };\n\n    /**\n     * Fix for Chrome in iOS\n     * See https://github.com/devote/HTML5-History-API/issues/29\n     */\n    var fastFixChrome = function(method, args) {\n        var isNeedFix = window.history !== windowHistory;\n        if (isNeedFix) {\n            window.history = windowHistory;\n        }\n        method.apply(windowHistory, args);\n        if (isNeedFix) {\n            window.history = historyObject;\n        }\n    };\n\n    /**\n     * Properties that will be replaced/added to object\n     * 'window.history', includes the object 'history.location',\n     * for a complete the work with the URL address\n     *\n     * @type {Object}\n     */\n    var historyDescriptors = {\n        /**\n         * @namespace history\n         * @param {String} [type]\n         * @param {String} [basepath]\n         */\n        \"redirect\": function(type, basepath) {\n            settings[\"basepath\"] = basepath = basepath == null ? settings[\"basepath\"] : basepath;\n            settings[\"type\"] = type = type == null ? settings[\"type\"] : type;\n            if (window.top == window.self) {\n                var relative = parseURL(null, false, true)._relative;\n                var path = windowLocation.pathname + windowLocation.search;\n                if (isSupportHistoryAPI) {\n                    path = path.replace(/([^\\/])$/, '$1/');\n                    if (relative != basepath && (new RegExp(\"^\" + basepath + \"$\", \"i\")).test(path)) {\n                        windowLocation.replace(relative);\n                    }\n                } else if (path != basepath) {\n                    path = path.replace(/([^\\/])\\?/, '$1/?');\n                    if ((new RegExp(\"^\" + basepath, \"i\")).test(path)) {\n                        windowLocation.replace(basepath + '#' + path.\n                            replace(new RegExp(\"^\" + basepath, \"i\"), type) + windowLocation.hash);\n                    }\n                }\n            }\n        },\n        /**\n         * The method adds a state object entry\n         * to the history.\n         *\n         * @namespace history\n         * @param {Object} state\n         * @param {string} title\n         * @param {string} [url]\n         */\n        pushState: function(state, title, url) {\n            historyPushState && fastFixChrome(historyPushState, arguments);\n            changeState(state, url);\n        },\n        /**\n         * The method updates the state object,\n         * title, and optionally the URL of the\n         * current entry in the history.\n         *\n         * @namespace history\n         * @param {Object} state\n         * @param {string} title\n         * @param {string} [url]\n         */\n        replaceState: function(state, title, url) {\n            delete stateStorage[windowLocation.href];\n            historyReplaceState && fastFixChrome(historyReplaceState, arguments);\n            changeState(state, url, true);\n        },\n        /**\n         * Object 'history.location' is similar to the\n         * object 'window.location', except that in\n         * HTML4 browsers it will behave a bit differently\n         *\n         * @namespace history\n         */\n        \"location\": {\n            set: function(value) {\n                window.location = value;\n            },\n            get: function() {\n                return isSupportHistoryAPI ? windowLocation : locationObject;\n            }\n        },\n        /**\n         * A state object is an object representing\n         * a user interface state.\n         *\n         * @namespace history\n         */\n        \"state\": {\n            get: function() {\n                return stateStorage[windowLocation.href] || null;\n            }\n        }\n    };\n\n    /**\n     * Properties for object 'history.location'.\n     * Object 'history.location' is similar to the\n     * object 'window.location', except that in\n     * HTML4 browsers it will behave a bit differently\n     *\n     * @type {Object}\n     */\n    var locationDescriptors = {\n        /**\n         * Navigates to the given page.\n         *\n         * @namespace history.location\n         */\n        assign: function(url) {\n            if (('' + url).indexOf('#') === 0) {\n                changeState(null, url);\n            } else {\n                windowLocation.assign(url);\n            }\n        },\n        /**\n         * Reloads the current page.\n         *\n         * @namespace history.location\n         */\n        reload: function() {\n            windowLocation.reload();\n        },\n        /**\n         * Removes the current page from\n         * the session history and navigates\n         * to the given page.\n         *\n         * @namespace history.location\n         */\n        replace: function(url) {\n            if (('' + url).indexOf('#') === 0) {\n                changeState(null, url, true);\n            } else {\n                windowLocation.replace(url);\n            }\n        },\n        /**\n         * Returns the current page's location.\n         *\n         * @namespace history.location\n         */\n        toString: function() {\n            return this.href;\n        },\n        /**\n         * Returns the current page's location.\n         * Can be set, to navigate to another page.\n         *\n         * @namespace history.location\n         */\n        \"href\": {\n            get: function() {\n                return parseURL()._href;\n            }\n        },\n        /**\n         * Returns the current page's protocol.\n         *\n         * @namespace history.location\n         */\n        \"protocol\": null,\n        /**\n         * Returns the current page's host and port number.\n         *\n         * @namespace history.location\n         */\n        \"host\": null,\n        /**\n         * Returns the current page's host.\n         *\n         * @namespace history.location\n         */\n        \"hostname\": null,\n        /**\n         * Returns the current page's port number.\n         *\n         * @namespace history.location\n         */\n        \"port\": null,\n        /**\n         * Returns the current page's path only.\n         *\n         * @namespace history.location\n         */\n        \"pathname\": {\n            get: function() {\n                return parseURL()._pathname;\n            }\n        },\n        /**\n         * Returns the current page's search\n         * string, beginning with the character\n         * '?' and to the symbol '#'\n         *\n         * @namespace history.location\n         */\n        \"search\": {\n            get: function() {\n                return parseURL()._search;\n            }\n        },\n        /**\n         * Returns the current page's hash\n         * string, beginning with the character\n         * '#' and to the end line\n         *\n         * @namespace history.location\n         */\n        \"hash\": {\n            set: function(value) {\n                changeState(null, ('' + value).replace(/^(#|)/, '#'), false, lastURL);\n            },\n            get: function() {\n                return parseURL()._hash;\n            }\n        }\n    };\n\n    /**\n     * Just empty function\n     *\n     * @return void\n     */\n    function emptyFunction() {\n        // dummy\n    }\n\n    /**\n     * Prepares a parts of the current or specified reference for later use in the library\n     *\n     * @param {string} [href]\n     * @param {boolean} [isWindowLocation]\n     * @param {boolean} [isNotAPI]\n     * @return {Object}\n     */\n    function parseURL(href, isWindowLocation, isNotAPI) {\n        var re = /(?:([\\w0-9]+:))?(?:\\/\\/(?:[^@]*@)?([^\\/:\\?#]+)(?::([0-9]+))?)?([^\\?#]*)(?:(\\?[^#]+)|\\?)?(?:(#.*))?/;\n        if (href && !isWindowLocation) {\n            var current = parseURL(), _pathname = current._pathname, _protocol = current._protocol;\n            // convert relative link to the absolute\n            href = /^(?:[\\w0-9]+\\:)?\\/\\//.test(href) ? href.indexOf(\"/\") === 0\n                ? _protocol + href : href : _protocol + \"//\" + current._host + (\n                href.indexOf(\"/\") === 0 ? href : href.indexOf(\"?\") === 0\n                    ? _pathname + href : href.indexOf(\"#\") === 0\n                    ? _pathname + current._search + href : _pathname.replace(/[^\\/]+$/g, '') + href\n                );\n        } else {\n            href = isWindowLocation ? href : windowLocation.href;\n            // if current browser not support History-API\n            if (!isSupportHistoryAPI || isNotAPI) {\n                // get hash fragment\n                href = href.replace(/^[^#]*/, '') || \"#\";\n                // form the absolute link from the hash\n                href = windowLocation.protocol + '//' + windowLocation.host + settings['basepath']\n                    + href.replace(new RegExp(\"^#[\\/]?(?:\" + settings[\"type\"] + \")?\"), \"\");\n            }\n        }\n        // that would get rid of the links of the form: /../../\n        anchorElement.href = href;\n        // decompose the link in parts\n        var result = re.exec(anchorElement.href);\n        // host name with the port number\n        var host = result[2] + (result[3] ? ':' + result[3] : '');\n        // folder\n        var pathname = result[4] || '/';\n        // the query string\n        var search = result[5] || '';\n        // hash\n        var hash = result[6] === '#' ? '' : (result[6] || '');\n        // relative link, no protocol, no host\n        var relative = pathname + search + hash;\n        // special links for set to hash-link, if browser not support History API\n        var nohash = pathname.replace(new RegExp(\"^\" + settings[\"basepath\"], \"i\"), settings[\"type\"]) + search;\n        // result\n        return {\n            _href: result[1] + '//' + host + relative,\n            _protocol: result[1],\n            _host: host,\n            _hostname: result[2],\n            _port: result[3] || '',\n            _pathname: pathname,\n            _search: search,\n            _hash: hash,\n            _relative: relative,\n            _nohash: nohash,\n            _special: nohash + hash\n        }\n    }\n\n    /**\n     * Initializing storage for the custom state's object\n     */\n    function storageInitialize() {\n        var storage = '';\n        if (sessionStorage) {\n            // get cache from the storage in browser\n            storage += sessionStorage.getItem(sessionStorageKey);\n        } else {\n            var cookie = document.cookie.split(sessionStorageKey + \"=\");\n            if (cookie.length > 1) {\n                storage += (cookie.pop().split(\";\").shift() || 'null');\n            }\n        }\n        try {\n            stateStorage = JSON.parse(storage) || {};\n        } catch(_e_) {\n            stateStorage = {};\n        }\n        // hang up the event handler to event unload page\n        addEvent(eventNamePrefix + 'unload', function() {\n            if (sessionStorage) {\n                // save current state's object\n                sessionStorage.setItem(sessionStorageKey, JSON.stringify(stateStorage));\n            } else {\n                // save the current 'state' in the cookie\n                var state = {};\n                if (state[windowLocation.href] = historyObject.state) {\n                    document.cookie = sessionStorageKey + '=' + JSON.stringify(state);\n                }\n            }\n        }, false);\n    }\n\n    /**\n     * This method is implemented to override the built-in(native)\n     * properties in the browser, unfortunately some browsers are\n     * not allowed to override all the properties and even add.\n     * For this reason, this was written by a method that tries to\n     * do everything necessary to get the desired result.\n     *\n     * @param {Object} object The object in which will be overridden/added property\n     * @param {String} prop The property name to be overridden/added\n     * @param {Object} [descriptor] An object containing properties set/get\n     * @param {Function} [onWrapped] The function to be called when the wrapper is created\n     * @return {Object|Boolean} Returns an object on success, otherwise returns false\n     */\n    function redefineProperty(object, prop, descriptor, onWrapped) {\n        // test only if descriptor is undefined\n        descriptor = descriptor || {set: emptyFunction};\n        // variable will have a value of true the success of attempts to set descriptors\n        var isDefinedSetter = !descriptor.set;\n        var isDefinedGetter = !descriptor.get;\n        // for tests of attempts to set descriptors\n        var test = {configurable: true, set: function() {\n            isDefinedSetter = 1;\n        }, get: function() {\n            isDefinedGetter = 1;\n        }};\n\n        try {\n            // testing for the possibility of overriding/adding properties\n            defineProperty(object, prop, test);\n            // running the test\n            object[prop] = object[prop];\n            // attempt to override property using the standard method\n            defineProperty(object, prop, descriptor);\n        } catch(_e_) {\n        }\n\n        // If the variable 'isDefined' has a false value, it means that need to try other methods\n        if (!isDefinedSetter || !isDefinedGetter) {\n            // try to override/add the property, using deprecated functions\n            if (object.__defineGetter__) {\n                // testing for the possibility of overriding/adding properties\n                object.__defineGetter__(prop, test.get);\n                object.__defineSetter__(prop, test.set);\n                // running the test\n                object[prop] = object[prop];\n                // attempt to override property using the deprecated functions\n                descriptor.get && object.__defineGetter__(prop, descriptor.get);\n                descriptor.set && object.__defineSetter__(prop, descriptor.set);\n            }\n\n            // Browser refused to override the property, using the standard and deprecated methods\n            if ((!isDefinedSetter || !isDefinedGetter) && object === window) {\n                try {\n                    // save original value from this property\n                    var originalValue = object[prop];\n                    // set null to built-in(native) property\n                    object[prop] = null;\n                } catch(_e_) {\n                }\n                // This rule for Internet Explorer 8\n                if ('execScript' in window) {\n                    /**\n                     * to IE8 override the global properties using\n                     * VBScript, declaring it in global scope with\n                     * the same names.\n                     */\n                    window['execScript']('Public ' + prop, 'VBScript');\n                } else {\n                    try {\n                        /**\n                         * This hack allows to override a property\n                         * with the set 'configurable: false', working\n                         * in the hack 'Safari' to 'Mac'\n                         */\n                        defineProperty(object, prop, {value: emptyFunction});\n                    } catch(_e_) {\n                    }\n                }\n                // set old value to new variable\n                object[prop] = originalValue;\n\n            } else if (!isDefinedSetter || !isDefinedGetter) {\n                // the last stage of trying to override the property\n                try {\n                    try {\n                        // wrap the object in a new empty object\n                        var temp = Object.create(object);\n                        defineProperty(Object.getPrototypeOf(temp) === object ? temp : object, prop, descriptor);\n                        for(var key in object) {\n                            // need to bind a function to the original object\n                            if (typeof object[key] === 'function') {\n                                temp[key] = object[key].bind(object);\n                            }\n                        }\n                        try {\n                            // to run a function that will inform about what the object was to wrapped\n                            onWrapped.call(temp, temp, object);\n                        } catch(_e_) {\n                        }\n                        object = temp;\n                    } catch(_e_) {\n                        // sometimes works override simply by assigning the prototype property of the constructor\n                        defineProperty(object.constructor.prototype, prop, descriptor);\n                    }\n                } catch(_e_) {\n                    // all methods have failed\n                    return false;\n                }\n            }\n        }\n\n        return object;\n    }\n\n    /**\n     * Adds the missing property in descriptor\n     *\n     * @param {Object} object An object that stores values\n     * @param {String} prop Name of the property in the object\n     * @param {Object|null} descriptor Descriptor\n     * @return {Object} Returns the generated descriptor\n     */\n    function prepareDescriptorsForObject(object, prop, descriptor) {\n        descriptor = descriptor || {};\n        // the default for the object 'location' is the standard object 'window.location'\n        object = object === locationDescriptors ? windowLocation : object;\n        // setter for object properties\n        descriptor.set = (descriptor.set || function(value) {\n            object[prop] = value;\n        });\n        // getter for object properties\n        descriptor.get = (descriptor.get || function() {\n            return object[prop];\n        });\n        return descriptor;\n    }\n\n    /**\n     * Wrapper for the methods 'addEventListener/attachEvent' in the context of the 'window'\n     *\n     * @param {String} event The event type for which the user is registering\n     * @param {Function} listener The method to be called when the event occurs.\n     * @param {Boolean} capture If true, capture indicates that the user wishes to initiate capture.\n     * @return void\n     */\n    function addEventListener(event, listener, capture) {\n        if (event in eventsList) {\n            // here stored the event listeners 'popstate/hashchange'\n            eventsList[event].push(listener);\n        } else {\n            // FireFox support non-standart four argument aWantsUntrusted\n            // https://github.com/devote/HTML5-History-API/issues/13\n            if (arguments.length > 3) {\n                addEvent(event, listener, capture, arguments[3]);\n            } else {\n                addEvent(event, listener, capture);\n            }\n        }\n    }\n\n    /**\n     * Wrapper for the methods 'removeEventListener/detachEvent' in the context of the 'window'\n     *\n     * @param {String} event The event type for which the user is registered\n     * @param {Function} listener The parameter indicates the Listener to be removed.\n     * @param {Boolean} capture Was registered as a capturing listener or not.\n     * @return void\n     */\n    function removeEventListener(event, listener, capture) {\n        var list = eventsList[event];\n        if (list) {\n            for(var i = list.length; --i;) {\n                if (list[i] === listener) {\n                    list.splice(i, 1);\n                    break;\n                }\n            }\n        } else {\n            removeEvent(event, listener, capture);\n        }\n    }\n\n    /**\n     * Wrapper for the methods 'dispatchEvent/fireEvent' in the context of the 'window'\n     *\n     * @param {Event|String} event Instance of Event or event type string if 'eventObject' used\n     * @param {*} [eventObject] For Internet Explorer 8 required event object on this argument\n     * @return {Boolean} If 'preventDefault' was called the value is false, else the value is true.\n     */\n    function dispatchEvent(event, eventObject) {\n        var eventType = ('' + (typeof event === \"string\" ? event : event.type)).replace(/^on/, '');\n        var list = eventsList[eventType];\n        if (list) {\n            // need to understand that there is one object of Event\n            eventObject = typeof event === \"string\" ? eventObject : event;\n            if (eventObject.target == null) {\n                // need to override some of the properties of the Event object\n                for(var props = ['target', 'currentTarget', 'srcElement', 'type']; event = props.pop();) {\n                    // use 'redefineProperty' to override the properties\n                    eventObject = redefineProperty(eventObject, event, {\n                        get: event === 'type' ? function() {\n                            return eventType;\n                        } : function() {\n                            return window;\n                        }\n                    });\n                }\n            }\n            // run function defined in the attributes 'onpopstate/onhashchange' in the 'window' context\n            ((eventType === 'popstate' ? window.onpopstate : window.onhashchange)\n                || emptyFunction).call(window, eventObject);\n            // run other functions that are in the list of handlers\n            for(var i = 0, len = list.length; i < len; i++) {\n                list[i].call(window, eventObject);\n            }\n            return true;\n        } else {\n            return dispatch(event, eventObject);\n        }\n    }\n\n    /**\n     * dispatch current state event\n     */\n    function firePopState() {\n        var o = document.createEvent ? document.createEvent('Event') : document.createEventObject();\n        if (o.initEvent) {\n            o.initEvent('popstate', false, false);\n        } else {\n            o.type = 'popstate';\n        }\n        o.state = historyObject.state;\n        // send a newly created events to be processed\n        dispatchEvent(o);\n    }\n\n    /**\n     * fire initial state for non-HTML5 browsers\n     */\n    function fireInitialState() {\n        if (isFireInitialState) {\n            isFireInitialState = false;\n            firePopState();\n        }\n    }\n\n    /**\n     * Change the data of the current history for HTML4 browsers\n     *\n     * @param {Object} state\n     * @param {string} [url]\n     * @param {Boolean} [replace]\n     * @param {string} [lastURLValue]\n     * @return void\n     */\n    function changeState(state, url, replace, lastURLValue) {\n        if (!isSupportHistoryAPI) {\n            // normalization url\n            var urlObject = parseURL(url);\n            // if current url not equal new url\n            if (urlObject._relative !== parseURL()._relative) {\n                // if empty lastURLValue to skip hash change event\n                lastURL = lastURLValue;\n                if (replace) {\n                    // only replace hash, not store to history\n                    windowLocation.replace(\"#\" + urlObject._special);\n                } else {\n                    // change hash and add new record to history\n                    windowLocation.hash = urlObject._special;\n                }\n            }\n        }\n        if (!isSupportStateObjectInHistory && state) {\n            stateStorage[windowLocation.href] = state;\n        }\n        isFireInitialState = false;\n    }\n\n    /**\n     * Event handler function changes the hash in the address bar\n     *\n     * @param {Event} event\n     * @return void\n     */\n    function onHashChange(event) {\n        // if not empty lastURL, otherwise skipped the current handler event\n        if (lastURL) {\n            // if checkUrlForPopState equal current url, this means that the event was raised popstate browser\n            if (checkUrlForPopState !== windowLocation.href) {\n                // otherwise,\n                // the browser does not support popstate event or just does not run the event by changing the hash.\n                firePopState();\n            }\n            // current event object\n            event = event || window.event;\n\n            var oldURLObject = parseURL(lastURL, true);\n            var newURLObject = parseURL();\n            // HTML4 browser not support properties oldURL/newURL\n            if (!event.oldURL) {\n                event.oldURL = oldURLObject._href;\n                event.newURL = newURLObject._href;\n            }\n            if (oldURLObject._hash !== newURLObject._hash) {\n                // if current hash not equal previous hash\n                dispatchEvent(event);\n            }\n        }\n        // new value to lastURL\n        lastURL = windowLocation.href;\n    }\n\n    /**\n     * The event handler is fully loaded document\n     *\n     * @param {*} [noScroll]\n     * @return void\n     */\n    function onLoad(noScroll) {\n        // Get rid of the events popstate when the first loading a document in the webkit browsers\n        setTimeout(function() {\n            // hang up the event handler for the built-in popstate event in the browser\n            addEvent('popstate', function(e) {\n                // set the current url, that suppress the creation of the popstate event by changing the hash\n                checkUrlForPopState = windowLocation.href;\n                // for Safari browser in OS Windows not implemented 'state' object in 'History' interface\n                // and not implemented in old HTML4 browsers\n                if (!isSupportStateObjectInHistory) {\n                    e = redefineProperty(e, 'state', {get: function() {\n                        return historyObject.state;\n                    }});\n                }\n                // send events to be processed\n                dispatchEvent(e);\n            }, false);\n        }, 0);\n        // for non-HTML5 browsers\n        if (!isSupportHistoryAPI && noScroll !== true && historyObject.location) {\n            // scroll window to anchor element\n            scrollToAnchorId(historyObject.location.hash);\n            // fire initial state for non-HTML5 browser after load page\n            fireInitialState();\n        }\n    }\n\n    /**\n     * handler url with anchor for non-HTML5 browsers\n     *\n     * @param e\n     */\n    function onAnchorClick(e) {\n        var event = e || window.event;\n        var target = event.target || event.srcElement;\n        var defaultPrevented = \"defaultPrevented\" in event ? event['defaultPrevented'] : event.returnValue === false;\n        if (target && target.nodeName === \"A\" && !defaultPrevented) {\n            var current = parseURL();\n            var expect = parseURL(target.getAttribute(\"href\", 2));\n            var isEqualBaseURL = current._href.split('#').shift() === expect._href.split('#').shift();\n            if (isEqualBaseURL && expect._hash) {\n                if (current._hash !== expect._hash) {\n                    historyObject.location.hash = expect._hash;\n                }\n                scrollToAnchorId(expect._hash);\n                if (event.preventDefault) {\n                    event.preventDefault();\n                } else {\n                    event.returnValue = false;\n                }\n            }\n        }\n    }\n\n    /**\n     * Scroll page to current anchor in url-hash\n     *\n     * @param hash\n     */\n    function scrollToAnchorId(hash) {\n        var target = document.getElementById(hash = (hash || '').replace(/^#/, ''));\n        if (target && target.id === hash && target.nodeName === \"A\") {\n            var rect = target.getBoundingClientRect();\n            window.scrollTo((documentElement.scrollLeft || 0), rect.top + (documentElement.scrollTop || 0)\n                - (documentElement.clientTop || 0));\n        }\n    }\n\n    /**\n     * Library initialization\n     *\n     * @return {Boolean} return true if all is well, otherwise return false value\n     */\n    function initialize() {\n        /**\n         * Get custom settings from the query string\n         */\n        var scripts = document.getElementsByTagName('script');\n        var src = (scripts[scripts.length - 1] || {}).src || '';\n        var arg = src.indexOf('?') !== -1 ? src.split('?').pop() : '';\n        arg.replace(/(\\w+)(?:=([^&]*))?/g, function(a, key, value) {\n            settings[key] = (value || (key === 'basepath' ? '/' : '')).replace(/^(0|false)$/, '');\n        });\n\n        /**\n         * sessionStorage throws error when cookies are disabled\n         * Chrome content settings when running the site in a Facebook IFrame.\n         * see: https://github.com/devote/HTML5-History-API/issues/34\n         */\n        try {\n            sessionStorage = window['sessionStorage'];\n        } catch(_e_) {}\n\n        /**\n         * hang up the event handler to listen to the events hashchange\n         */\n        addEvent(eventNamePrefix + 'hashchange', onHashChange, false);\n\n        // a list of objects with pairs of descriptors/object\n        var data = [locationDescriptors, locationObject, eventsDescriptors, window, historyDescriptors, historyObject];\n\n        // if browser support object 'state' in interface 'History'\n        if (isSupportStateObjectInHistory) {\n            // remove state property from descriptor\n            delete historyDescriptors['state'];\n        }\n\n        // initializing descriptors\n        for(var i = 0; i < data.length; i += 2) {\n            for(var prop in data[i]) {\n                if (data[i].hasOwnProperty(prop)) {\n                    if (typeof data[i][prop] === 'function') {\n                        // If the descriptor is a simple function, simply just assign it an object\n                        data[i + 1][prop] = data[i][prop];\n                    } else {\n                        // prepare the descriptor the required format\n                        var descriptor = prepareDescriptorsForObject(data[i], prop, data[i][prop]);\n                        // try to set the descriptor object\n                        if (!redefineProperty(data[i + 1], prop, descriptor, function(n, o) {\n                            // is satisfied if the failed override property\n                            if (o === historyObject) {\n                                // the problem occurs in Safari on the Mac\n                                window.history = historyObject = data[i + 1] = n;\n                            }\n                        })) {\n                            // if there is no possibility override.\n                            // This browser does not support descriptors, such as IE7\n\n                            // remove previously hung event handlers\n                            removeEvent(eventNamePrefix + 'hashchange', onHashChange, false);\n\n                            // fail to initialize :(\n                            return false;\n                        }\n\n                        // create a repository for custom handlers onpopstate/onhashchange\n                        if (data[i + 1] === window) {\n                            eventsList[prop] = eventsList[prop.substr(2)] = [];\n                        }\n                    }\n                }\n            }\n        }\n\n        // redirect if necessary\n        if (settings['redirect']) {\n            historyObject['redirect']();\n        }\n\n        // If browser does not support object 'state' in interface 'History'\n        if (!isSupportStateObjectInHistory && JSON) {\n            storageInitialize();\n        }\n\n        // track clicks on anchors\n        if (!isSupportHistoryAPI) {\n            document[addEventListenerName](eventNamePrefix + \"click\", onAnchorClick, false);\n        }\n\n        if (document.readyState === 'complete') {\n            onLoad(true);\n        } else {\n            if (!isSupportHistoryAPI && parseURL()._relative !== settings[\"basepath\"]) {\n                isFireInitialState = true;\n            }\n            /**\n             * Need to avoid triggering events popstate the initial page load.\n             * Hang handler popstate as will be fully loaded document that\n             * would prevent triggering event onpopstate\n             */\n            addEvent(eventNamePrefix + 'load', onLoad, false);\n        }\n\n        // everything went well\n        return true;\n    }\n\n    /**\n     * Starting the library\n     */\n    if (!initialize()) {\n        // if unable to initialize descriptors\n        // therefore quite old browser and there\n        // is no sense to continue to perform\n        return;\n    }\n\n    /**\n     * If the property history.emulate will be true,\n     * this will be talking about what's going on\n     * emulation capabilities HTML5-History-API.\n     * Otherwise there is no emulation, ie the\n     * built-in browser capabilities.\n     *\n     * @type {boolean}\n     * @const\n     */\n    historyObject['emulate'] = !isSupportHistoryAPI;\n\n    /**\n     * Replace the original methods on the wrapper\n     */\n    window[addEventListenerName] = addEventListener;\n    window[removeEventListenerName] = removeEventListener;\n    window[dispatchEventName] = dispatchEvent;\n\n})(window);//@ sourceURL=main/history.iegte8.js"
));
require.register("main/eventspol.js", Function("exports, require, module",
"!this.addEventListener && this.Element && (function () {\n   function addToPrototype(name, method) {\n      Window.prototype[name] = HTMLDocument.prototype[name] = Element.prototype[name] = method;\n   }\n \n   var registry = [];\n \n   addToPrototype(\"addEventListener\", function (type, listener) {\n      var target = this;\n \n      registry.unshift({\n         __listener: function (event) {\n            event.currentTarget = target;\n            event.pageX = event.clientX + document.documentElement.scrollLeft;\n            event.pageY = event.clientY + document.documentElement.scrollTop;\n            event.preventDefault = function () { event.returnValue = false };\n            event.relatedTarget = event.fromElement || null;\n            event.stopPropagation = function () { event.cancelBubble = true };\n            event.relatedTarget = event.fromElement || null;\n            event.target = event.srcElement || target;\n            event.timeStamp = +new Date;\n \n            listener.call(target, event);\n         },\n         listener: listener,\n         target: target,\n         type: type\n      });\n \n      this.attachEvent(\"on\" + type, registry[0].__listener);\n   });\n \n   addToPrototype(\"removeEventListener\", function (type, listener) {\n      for (var index = 0, length = registry.length; index < length; ++index) {\n         if (registry[index].target == this && registry[index].type == type && registry[index].listener == listener) {\n            return this.detachEvent(\"on\" + type, registry.splice(index, 1)[0].__listener);\n         }\n      }\n   });\n \n   addToPrototype(\"dispatchEvent\", function (eventObject) {\n      try {\n         return this.fireEvent(\"on\" + eventObject.type, eventObject);\n      } catch (error) {\n         for (var index = 0, length = registry.length; index < length; ++index) {\n            if (registry[index].target == this && registry[index].type == eventObject.type) {\n               registry[index].call(this, eventObject);\n            }\n         }\n      }\n   });\n})();\n//@ sourceURL=main/eventspol.js"
));
require.register("main/reduce.js", Function("exports, require, module",
"if ('function' !== typeof Array.prototype.reduce) {\n  Array.prototype.reduce = function(callback, opt_initialValue){\n    'use strict';\n    if (null === this || 'undefined' === typeof this) {\n      // At the moment all modern browsers, that support strict mode, have\n      // native implementation of Array.prototype.reduce. For instance, IE8\n      // does not support strict mode, so this check is actually useless.\n      throw new TypeError(\n          'Array.prototype.reduce called on null or undefined');\n    }\n    if ('function' !== typeof callback) {\n      throw new TypeError(callback + ' is not a function');\n    }\n    var index = 0, length = this.length >>> 0, value, isValueSet = false;\n    if (1 < arguments.length) {\n      value = opt_initialValue;\n      isValueSet = true;\n    }\n    for ( ; length > index; ++index) {\n      if (!this.hasOwnProperty(index)) continue;\n      if (isValueSet) {\n        value = callback(value, this[index], index, this);\n      } else {\n        value = this[index];\n        isValueSet = true;\n      }\n    }\n    if (!isValueSet) {\n      throw new TypeError('Reduce of empty array with no initial value');\n    }\n    return value;\n  };\n}\n//@ sourceURL=main/reduce.js"
));
require.register("main/item.js", Function("exports, require, module",
"\n/**\n * Module dependencies\n */\n\nvar o = jQuery = require('jquery');;\nvar inherit = require('inherit');\nvar config = require('./config');\nvar swipe = require('swipe');\nvar Emitter = require('emitter');\nvar supera = require('superagent');\nvar pp = require('prettyphoto');\nvar ua = require('user-agent-parser')();\nvar debug = require('debug')('ch:item');\n\n/**\n * Expose `Item` component\n */\n\nmodule.exports = Item;\n\n/**\n * Item costructor\n *\n * @param {jQuery} el\n * @param {Stream} stream\n * @api public\n */\nfunction Item(el, stream){\n  if (!(this instanceof Item)) return new Item(el, stream);\n  Emitter.call(this);\n  this.el = o(el);\n  this.stream = stream;\n  this.full = this.el.find('.full-description');\n  this.retrieveData();\n\n  this.gallerylink = this.el.find('.gallery-link'); \n  this.gallery();\n  this.el.on('click','.close', this.close.bind(this));\n  this.css3 = this.el.css('-webkit-transform');\n  return this;\n};\n\n/**\n * Inherit from 'Emitter'\n */\n\ninherit(Item, Emitter);\n\n/**\n * Render the item element\n *\n * @api public\n */\n\nItem.prototype.render = function(){\n  return this.el;\n};\n/**\n * Render the Gallery\n *\n * @api public\n */\n\nItem.prototype.gallery = function(){\n  this.gallerylink.on('click', function(ev){\n    ev.preventDefault();\n    ev.stopPropagation();\n    var images = o(this).data('images').split(','); \n    var titles = o(this).data('titles').split(','); \n    var descriptions = o(this).data('descriptions').split(','); \n  //  console.log('-> images -> ', images);\n    var api_images = images\n    , api_titles = titles\n    , api_descriptions = descriptions;\n // console.log('-> o.prettyPhoto -> ', o.prettyPhoto);\n   o.fn.prettyPhoto({social_tools: '',\n   markup: '<div class=\"pp_pic_holder\"> \\\n\t\t\t\t\t\t<div class=\"ppt\">&nbsp;</div> \\\n\t\t\t\t\t\t<div class=\"pp_top\"> \\\n\t\t\t\t\t\t\t<div class=\"pp_left\"></div> \\\n\t\t\t\t\t\t\t<div class=\"pp_middle\"></div> \\\n\t\t\t\t\t\t\t<div class=\"pp_right\"></div> \\\n\t\t\t\t\t\t</div> \\\n\t\t\t\t\t\t<div class=\"pp_content_container\"> \\\n\t\t\t\t\t\t\t<div class=\"pp_left\"> \\\n\t\t\t\t\t\t\t<div class=\"pp_right\"> \\\n\t\t\t\t\t\t\t\t<div class=\"pp_content\"> \\\n\t\t\t\t\t\t\t\t\t<div class=\"pp_loaderIcon\"></div> \\\n\t\t\t\t\t\t\t\t\t<div class=\"pp_fade\"> \\\n\t\t\t\t\t\t\t\t\t\t<a href=\"#\" class=\"pp_expand\" title=\"Expand the image\">Expand</a> \\\n\t\t\t\t\t\t\t\t\t\t<div class=\"pp_hoverContainer\"> \\\n\t\t\t\t\t\t\t\t\t\t\t<a class=\"pp_next\" href=\"#\">next</a> \\\n\t\t\t\t\t\t\t\t\t\t\t<a class=\"pp_previous\" href=\"#\">previous</a> \\\n\t\t\t\t\t\t\t\t\t\t</div> \\\n\t\t\t\t\t\t\t\t\t\t<div id=\"pp_full_res\"></div> \\\n\t\t\t\t\t\t\t\t\t\t<div class=\"pp_details\"> \\\n\t\t\t\t\t\t\t\t\t\t\t<div class=\"pp_nav\"> \\\n\t\t\t\t\t\t\t\t\t\t\t\t<p class=\"currentTextHolder\">0/0</p> \\\n\t\t\t\t\t\t\t\t\t\t\t</div> \\\n\t\t\t\t\t\t\t\t\t\t\t<p class=\"pp_description\"></p> \\\n\t\t\t\t\t\t\t\t\t\t\t<div class=\"pp_social\">{pp_social}</div> \\\n\t\t\t\t\t\t\t\t\t\t\t<a class=\"pp_close\" href=\"#\">Close</a> \\\n\t\t\t\t\t\t\t\t\t\t</div> \\\n\t\t\t\t\t\t\t\t\t</div> \\\n\t\t\t\t\t\t\t\t</div> \\\n\t\t\t\t\t\t\t</div> \\\n\t\t\t\t\t\t\t</div> \\\n\t\t\t\t\t\t</div> \\\n\t\t\t\t\t\t<div class=\"pp_bottom\"> \\\n\t\t\t\t\t\t\t<div class=\"pp_left\"></div> \\\n\t\t\t\t\t\t\t<div class=\"pp_middle\"></div> \\\n\t\t\t\t\t\t\t<div class=\"pp_right\"></div> \\\n\t\t\t\t\t\t</div> \\\n\t\t\t\t\t</div> \\\n\t\t\t\t\t<div class=\"pp_overlay\"></div>'\n\n   \n   \n   \n   });\n   o.prettyPhoto.open(api_images, api_titles, api_descriptions);\n  })\n};\n\nItem.prototype.content = function(fn){\n  fn = fn || function(){};\n  if (this.opened) return;\n  debug('content');\n  this.opened = true;\n  this.el.addClass('opened-item');\n  this.stream.relayout();\n  var offsetY = this.el;\n  o('html, body, document').animate({\n    scrollTop: o(offsetY).offset().top\n  });\n\n  var self = this;\n\n  if(this.el.hasClass('youtube')) {\n    var wrap = this.el.find('.wrap a.thumbnail');\n    var code = this.el.find('.video').data('code');\n    this.el.initcontent = wrap.html();\n    var browser = ua.browser.name;\n    var html = '';\n    if( browser=='Firefox' ) html = '&html5=1';\n\n    var iframe = o('<iframe>', {\n           src: \"//www.youtube.com/embed/\"+code+\"?rel=0&autoplay=1\" + html\n         ,  width: \"477\"\n         ,  height: \"450\"\n         ,  frameborder: \"0\"\n         ,  webkitAllowFullScreen: 1\n         ,  mozallowfullscreen: 1\n         ,  allowFullScreen: 1\n        });\n   wrap.html(iframe);\n\n  } else {\n    this.parse(function(){\n      self.stream.relayout();\n    });\n  }\n  this.stream.emit('item-open', self);\n  this.emit('open');\n};\n\n\nItem.prototype.load = function(url, fn) {\n  fn = fn || function(){};\n  debug('load');\n  var self = this;\n  supera\n   .get(url)\n   .end(function(res){\n      var html = o(res.text);\n      self.description(html);\n      self.stream.relayout();\n      self.content();\n      fn();\n   });\n};\n/**\n * Open\n *\n * Emits:\n *\n *  'open'\n *  'item-open' in home instance\n *\n * @api public\n */\n\nItem.prototype.open = function(url){\n  if (this.opened) return;\n  debug('opened');\n  var  self = this;\n  if (this.isempty()){ self.load(url);}\n  else {self.content();}\n};\n\n\nItem.prototype.parse = function(fn){\n  fn = fn || function(){};\n  debug('parse');\n \n  var self = this;\n  setTimeout(function(){\n    if (addthis) addthis.toolbox(\".addthis_toolbox\");\n    FB.XFBML.parse(self.el.get(0), function(){\n      debug('facebook parse');\n      self.el.find('.fb-comments span').css('height', '100%');\n      self.loading = false;\n      fn();\n      return;\n    });\n  }, 1000);\n  fn();\n};\n\n/**\n * Close item\n *\n * Emits:\n *\n *  'close'\n *  'items-open' in home instance\n *\n * @api public\n */\n\nItem.prototype.close = function(){\n  if (!this.opened) return;\n  debug('close');\n  if(this.el.hasClass('youtube')) {\n    var wrap = this.el.find('.wrap a.thumbnail');\n    var iframe =  this.el.initcontent;\n    wrap.html(iframe);\n  }\n  this.el.removeClass('opened-item');\n  this.stream.emit('item-close', self);\n  this.emit('close');\n  this.opened = false;\n};\n\n/**\n * Retrieve data from markup\n */\n\nItem.prototype.retrieveData = function() {\n  this.size = this.el.data('size');\n  this.id = this.el.data('post');\n  this.slug = this.el.data('slug');\n  this.stream.items[this.id] = this;\n};\n\n/**\n * Set the html of full description\n *\n * @param {jQuery} html\n * @api private\n */\n\nItem.prototype.description = function(html) {\n  this.full = html;\n  this.el\n    .height('auto')\n    .append(html);\n };\n\n/**\n * Test if the item is empty\n *\n * @api public\n */\n\nItem.prototype.isempty = function(){\n  var isempty =  !(this.full && this.full.children().length);\n  debug('is empty: `%s`', isempty);\n  return isempty;\n};\n\n//@ sourceURL=main/item.js"
));
require.register("main/stream.js", Function("exports, require, module",
"\n/**\n * Module dependencies\n */\n\nvar o = jQuery = require('jquery');\nvar iso = require('isotope');\n//var infinitescroll = require('infinite-scroll');\n//var behaviors = require('./manual-trigger');\nvar Item = require('./item');\nvar inherit = require('inherit');\nvar Emitter = require('emitter');\nvar supera = require('superagent');\nvar debug = require('debug')('ch:stream');\n\n/**\n * Expose `stream` component\n */\n\nmodule.exports = Stream;\n\nfunction Stream(){\n  if (!(this instanceof Stream)) return new Stream();\n  this.els = {\n    filters: []\n  };\n  this.currentitem = null;\n};\n/**\n * Inherit from 'Emitter'\n */\n\ninherit(Stream, Emitter);\n\n\n/**\n * Isotope stuff\n *\n * @param {Object} options\n * @api private\n */\n\nStream.prototype.isotope = function(options){\n  // Options\n  options = options || {};\n  this.els = {\n    container: o('.isotope-container'),\n    filters: this.els.filters\n\n  };\n  \n  this.items = {};\n\n  var w = o(window).outerWidth();\n  var itemW = w > 482 ? 240 : 158;\n  var options = {\n    width: itemW,\n    height: itemW\n  }\n  this.currentitem = null;\n\n  this.item = {\n    width: options.width || 240,\n    height: options.height || 240,\n    classname: options.classname || 'item'\n  };\n\n  var item_selector = '.' + this.item.classname;\n\n  // Init Isotope\n  this.els.container.isotope({\n    itemSelector : item_selector,\n    masonry: {\n      columnWidth: this.item.width\n    },\n    getSortData : {\n      menu_order : function ( el ) {\n        return parseFloat( el.data('order') + el.data('date'));\n      },\n    },\n    sortBy : 'menu_order',\n    sortAscending : false\n  });\n  this.init = true;\n  //this.infinitescroll(); \n  this.loadmore();\n  this.retrieveItems();\n  this.on('item-open', this.onitemopen.bind(this));\n  this.on('item-close', this.onitemclose.bind(this));\n\n};\n\nStream.prototype.unset = function(){\n  this.init = false;\n};\n/**\n * Load More\n * *\n * @api public\n*\n*/\n\nStream.prototype.loadmore = function(){\n  debug('Load More');\n  var container = this.els.container;\n  var count = container.find('.item').length;\n  self = this;\n  container.on('click', '.loadmore a', function(e){\n    e.preventDefault();\n    var url = o(this).attr('href');\n    url = url.split(\"?\")[0].split(\"#\")[0];\n    supera\n    .get(url)\n    .end(function(res){\n      var j = 0;\n      var newElements = o(res.text).find('.item');\n      o.each( o( newElements ),function(i, e){\n        if(self.isitemloaded(o(e).data('post'))){\n          self.insert(e);\n        }\n        j++;\n      });\n      if(count > j) o(\".navigation\").hide();\n      var paging = o(res.text).find('.loadmore a');\n      if(paging.length > 0){\n        o('.navigation').remove();\n        o('#content').append(o(res.text).find('.navigation'));\n      } else {\n        o('.navigation').remove();\n      }\n    })\n  });\n}\n\n\n/**\n * Infinite Scroll\n * *\n * @api public\n*\n*/\n\nStream.prototype.infinitescroll = function(){\n   debug('infinite scroll');\n   var container = this.els.container;\n   var count = container.find('.item').length;\n   var self = this;\n   container.infinitescroll({\n    navSelector  : \".navigation\",\n    nextSelector : \".loadmore a\",\n    itemSelector : \".item\",\n   // behavior : \"twitter\",\n    loading: {\n      finishedMsg: 'No more pages to load.',\n      img: 'http://i.imgur.com/qkKy8.gif'\n    }\n  },\n  function( newElements ) {\n    //container.isotope( 'appended', o( newElements ) ); \n    var j = 0;\n    o.each( o( newElements ),function(i, e){\n      if(self.isitemloaded(o(e).data('post'))){\n        self.insert(e);\n        j++;\n      }\n    });\n    if(count > j) o(\".navigation\").hide();\n\n  });\n  o(window).unbind('.infscr');\n\n  o(\"#content\").on('click','.loadmore a',function(e){\n    e.preventDefault();\n    console.log('clieck!!!');\n    container.infinitescroll('retrieve');\n    //o(document).trigger('retrieve.infscr');\n  });\n   // remove the paginator when we're done.\n  o(document).ajaxError(function(e,xhr,opt){\n    if (xhr.status == 404) o(\".navigation\").remove();\n  });\n};\n\n/**\n* Retrieve initial items from the html markup\n*\n* @api public\n*/\n\nStream.prototype.retrieveItems = function(){\n  var self = this;\n  o.each(this.els.container.find('.item'), function(i, el){\n    Item(el, self);\n  });\n};\n\n/**\n* Refresh the layout\n*\n* @param {Function} fn (optional)\n*\n* @api public\n*/\n\nStream.prototype.relayout = function(fn){\n  debug('relayout');\n  this.els.container.isotope('reLayout', fn || function(){});\n};\n\n\nStream.prototype.filter = function(selector, fn){\n  fn = fn || function(){};\n  debug('filter');\n  if (this.currentitem) {\n    this.currentitem.close();\n    this.currentitem = null;\n  }\n  var fls = '*'; \n  if(selector != '' ){\n    var index = o.inArray(selector, this.els.filters);\n    if( index == -1 ){ \n      this.els.filters.push( selector );\n      o('#filters_menus .'+selector).addClass('current');\n    }\n    else { \n      this.els.filters.splice(index, 1); \n      o('#filters_menus .'+selector).removeClass('current');\n    }\n    if (this.els.filters.length > 0) { fls = '.' +  this.els.filters.join(', .');}\n  } else {\n    this.els.filters.length = 0;\n    o('#filters_menus li').removeClass('current')\n  }\n  this.els.container.isotope({ filter: fls });\n};\n\nStream.prototype.insert = function(data, fn){\n  fn = fn || function(){};\n  var newitems = o(data);\n  var self = this;\n  o.each( newitems ,function(i, e){\n    if(o(e).hasClass('item')) {\n      Item(e, self);\n      self.els.container.isotope('insert', o(e));\n    }\n  });\n\n  this.relayout();\n};\n\nStream.prototype.onitemclose = function(item){\n  debug('item close');\n  this.currentitem = null;\n  this.relayout();\n};\n\nStream.prototype.onitemopen = function(item){\n  debug('item open');\n  if (this.currentitem && item.id != this.currentitem.id) {\n    this.currentitem.close();\n  }\n  this.currentitem = item;\n  this.relayout();\n};\n\n/**\n * Load a post and print the response into the item box\n *\n * @param {String} slug\n * @api private\n */\n\nStream.prototype.loadItem = function(path, fn) {\n  fn = fn || function(){};\n  var item = this.getItemBySlug(path);\n  if(item){\n    debug('load item: `%s` ', item.id);\n    item.open(path);\n    fn(true);\n  } else { \n    fn(false); \n  }\n};\n\n/**\n * Get an Item through ofgiven slug\n *\n * @api public\n */\n\nStream.prototype.getItemBySlug = function(slug){\n  debug('get item by `%s` slug', slug);\n  var postname = slug.replace(/\\//g, '');\n\n  var el = this.els.container.find('.item[data-slug=' + postname + ']');\n\n  var id = el.data('post');\n\n  debug('post item found: `%s`', id);\n  return this.items ? this.items[id] : null;\n};\n\n\nStream.prototype.isitemloaded = function(id){\n  if(!this.items[id])\n    return true;\n  else\n    return false;\n};\n//@ sourceURL=main/stream.js"
));
require.register("main/cubpage.js", Function("exports, require, module",
"\n  /**\n   * Module dependencies\n   */\n\n  var o = jQuery = require('jquery');\n  var dialog = require('dialog');\n  var ua = require('user-agent-parser')();\n\n  /**\n   * Expose `dialog` component\n   */\n\n  module.exports = Cubpage;\n\n  function Cubpage(){\n    if (!(this instanceof Cubpage)) return new Cubpage();\n    var slider = o('.cubvideo');\n    if(slider.length > 0) {\n      slider.on('click', 'a', function(e){\n        e.preventDefault();\n        e.stopPropagation();\n        var browser = ua.browser.name;\n        var html = '';\n        if( browser=='Firefox' ) html = '&html5=1';\n        var iframe = o('<iframe>', {\n           src: \"//www.youtube.com/embed/dqKFgk8SJlE?rel=0&autoplay=1\" + html \n         ,  width: \"840\"\n         ,  height: \"510\"\n         ,  frameborder: \"0\"\n         ,  webkitAllowFullScreen: 1\n         ,  mozallowfullscreen: 1\n         ,  allowFullScreen: 1\n        });\n        slider.html(iframe);\n      })\n    };\n  };\n\n//@ sourceURL=main/cubpage.js"
));
require.register("main/routing.js", Function("exports, require, module",
"\n/**\n * Module dependecies\n */\nvar o = jQuery = require('jquery');\nvar page = require('page');\nvar qs = require('querystring');\nvar conf = require('./config')();\nvar Stream = require('./stream');\nvar Cubpage = require('./cubpage');\nvar Request = require('./request')();\nvar ua = require('user-agent-parser')();\nvar debug = require('debug')('ch:Routing');\nvar commander = Stream();\n/**\n * Expose 'routing' component\n */\n\nmodule.exports = Routing;\n\nfunction Routing(){\n  \n  var unsupported = 'IE' == ua.browser.name && ua.browser.major < 10;\n  if(unsupported) {\n    debug('apply basic routing');\n    var host = conf.basedir;\n    var path = document.location.pathname.substr(host.length);\n    debug('path detected: %s', path)\n    var main = o('#primary');\n    if( main.data('type') == 'home' ||\n        main.data('type') == 'single' ||\n        main.data('type') == 'tax' ) {\n      isoloadie( path );\n    } else {\n      Cubpage();\n    }\n    return;\n  }\n  page.base(conf.basedir);\n  page('*', parse, analytics );\n  page('/', isoload); \n  page('/#', isoload); \n  page('/tag/:tag',  isoload );\n  page('/category/:category',   isoload );\n  page('/source/:source', isoload );\n  page('/rank/:rank',  isoload );\n  page('/resources/:view?/:filter?',  resourceload);\n  page('/:post',  postload);\n  page('/:page',  pageload);  \n  page();\n}\n\n\n\n\nfunction parse(ctx, next) {\n  debug('parse: ' + ctx.path);\n  ctx.query = qs.parse(ctx.querystring);\n  next();\n}\n\nfunction analytics(ctx, next){\n  debug('analytics page view: ' + ctx.path);\n  ga('send', {\n      'hitType': 'pageview',\n      'page':  ctx.path,\n  });\n  next();\n}\n\nfunction setcurrentmenu(ctx){\n  var slug = ctx.params.page ? ctx.params.page : 'menu-item-home';\n  var currentmenu = o('#menu-main-menu .current-menu-item');\n  if( !currentmenu.hasClass(slug) ) {\n    currentmenu.removeClass('current-menu-item');\n    o('#menu-main-menu .' + slug).addClass('current-menu-item');\n  }\n}\nfunction isoloadie(path){\n  debug('isotope IE load: ' + path );\n  o('#main').on('click', 'a', function(e){\n    var href = o(this).attr('href');\n    if (/localhost|cubscouts\\.org/.test(href)){\n      e.preventDefault();\n      var slug = o(this).data('slug');  \n      if( slug ) \n        commander.loadItem(slug);\n\n      if((/\\/category\\/.*\\/$/).test(href) ||\n         (/\\/tag\\/.*\\/$/).test(href) ||\n         (/\\/source\\/.*\\/$/).test(href) ||\n         (/\\/rank\\/.*\\/$/).test(href) ){\n        var items = o('.item');\n        var postids = [];\n        o.each(items, function(i,v){\n          postids.push(o(v).data('post'));\n        });\n        var ipath = href.match(/cubscouts\\.org(.*)/);\n        //var ipath = href.match(/localhost(.*)/);\n        Request.postgridload(ipath[1], postids, function(res){\n          if(res.length > 2)\n            commander.insert(res);\n        });\n        /*var filter = ctx.params.source ? ctx.params.source : \n            ctx.params.rank ? ctx.params.rank : \n            ctx.params.tag ? ctx.params.tag : \n            ctx.params.category ? ctx.params.category : '';*/\n        var filter = href.match(/cubscouts\\.org\\/([\\w\\d]*)\\/([\\w\\d-]*)/);\n        if(filter) commander.filter(filter[2]);\n      }\n    }\n  });\n   /* init isotope */\n  if(!commander.init ) commander.isotope();\n}\n\n/**\n * isoload\n */\nfunction isoload(ctx, next){\n  debug('isotope load: ' + ctx.path );\n  /* set title */\n  o('#header_title').html('WELCOME TO THE <span>HUB</span>');\n  /* set current Menu */\n  setcurrentmenu(ctx);\n  \n  var items = o('.item');\n  var postids = [];\n  o.each(items, function(i,v){\n    postids.push(o(v).data('post'));\n  });\n\n  /* init isotope */\n  if(!commander.init && ctx.init){\n    commander.isotope();\n  } else if(!commander.init && !ctx.init ) {\n     Request.load(ctx.canonicalPath, function(){\n      //setTimeout(commander.isotope(), 1000); \n      commander.isotope(); \n      //next();\n    });\n  }\n  else {\n    debug('request more posts');\n    Request.postgridload(ctx.canonicalPath, postids, function(res){\n      if(res.length > 2) commander.insert(res);\n      var paging = o(res).find('.loadmore a');\n      if(paging.length > 0){\n        o('.navigation').remove();\n        o('#content').append(o(res).next('.navigation'));\n      } else {\n        o('.navigation').remove();\n      }\n\n    });\n   \n  } \n  /* filters */\n  var filter = ctx.params.source ? ctx.params.source : \n      ctx.params.rank ? ctx.params.rank : \n      ctx.params.tag ? ctx.params.tag : \n      ctx.params.category ? ctx.params.category : '';\n  if(filter || filter == '') commander.filter(filter); \n\n\n  /*if(filter == ''  ) { \n    ctx.state.filter = '';\n    ctx.save();\n  }\n  else{\n    if(ctx.state.filter)\n      ctx.state.filter += '.' + filter;\n    else \n      ctx.state.filter = '.' + filter;\n    ctx.save();\n  }\n\n  var curtype = o('#primary').data('type');\n    if(postids.length > 0){\n    Request.postgridload(ctx.canonicalPath, postids, function(res){\n    if(res.length > 2)\n      commander.insert(res);\n    });\n    var filter = ctx.params.source ? ctx.params.source : \n      ctx.params.rank ? ctx.params.rank : \n      ctx.params.tag ? ctx.params.tag : \n      ctx.params.category ? ctx.params.category : '';\n    console.log('-> filter -> ', filter);\n    if(filter) commander.filter(filter); \n  } else\n    Request.load(ctx.canonicalPath, function(){\n      var type = o('#primary').data('type');\n      setTimeout(commander.isotope(), 1000); \n      next();\n    });*/\n}\n/**\n * resource load\n */\nfunction resourceload(ctx, next){\n  ctx.params.page  = 'resources';\n  o('#header_title').html('RE<span>SOURCES</span>');\n  setcurrentmenu(ctx);\n\n  commander.unset();\n  if(ctx.query.view) {\n    var rcontent = o('.resources_subcontent');\n    if(!rcontent.hasClass(ctx.query.view + '_view')){ \n      var otherview = ctx.query.view == 'grid' ? 'list_view' : 'grid_view';\n      rcontent.removeClass(otherview);\n      rcontent.addClass(ctx.query.view + '_view');\n    }\n  }\n  else\n    Request.load(ctx.canonicalPath);\n\n  debug('resource load: ' + ctx.path );\n}\n/**\n * post load\n */\n\nfunction postload(ctx, next){\n  debug('post load: ' + ctx.path );\n  o('#header_title').html('WELCOME TO THE <span>HUB</span>');\n  if(!commander.init) commander.isotope();\n  commander.loadItem(ctx.path,\n    function(nextto){\n      if (nextto){ \n        setcurrentmenu(ctx);\n      }\n      else\n        next();\n    });\n}\n\n/**\n * pageload\n */\nfunction pageload(ctx, next){\n  debug('page load: ' + ctx.path );\n  setcurrentmenu(ctx);\n  commander.unset();\n  if(ctx.params.page == 'contests'){\n    o('#header_title').html('CON<span>TESTS</span>');\n    Request.load(ctx.canonicalPath);\n  }\n  if(ctx.params.page == 'experience-cub-scouting'){\n    o('#header_title').html('EXPERIENCE <span>CUB SCOUTING</span>');\n    Request.load(ctx.canonicalPath, function(res){\n      Cubpage();\n    });\n  }\n}\n\n//@ sourceURL=main/routing.js"
));
require.register("main/request.js", Function("exports, require, module",
"/**\n * Module dependencies\n */\n\nvar o = jQuery = require('jquery');\nvar supera = require('superagent');\n\n/**\n * Expose 'request' component\n */\n\nmodule.exports = Request;\n\nfunction Request(){\n  if (!(this instanceof Request)) return new Request;\n}\n\n/**\n * load \n */\n\nRequest.prototype.load = function(url, fn) {\n  fn = fn || function(){};\n  var el = o('#main');\n  el.addClass('loading');\n  el.empty();\n  supera\n  .get(url)\n  .end(function(res){\n    el.append(res.text); \n    el.removeClass('loading');\n    fn(res);\n  });\n};\n\n/**\n * item load \n */\n\nRequest.prototype.itemload = function(url, fn) {\n  fn = fn || function(){};\n  supera\n  .get(url)\n  .end(function(res){\n    var item = o(res.text);\n    var postid = item.data('post');\n    if ( postid ){\n      var el = o( '#post-' + postid );\n      var els = o( '.item');\n      el.addClass('loading');\n      el.append(res.text); \n      els.removeClass('opened-item');\n      el.addClass('opened-item');\n      el.removeClass('loading');\n      fn(true);\n    } else {\n      fn(false);\n    }\n  });\n};\n/**\n * item load \n */\n\nRequest.prototype.postgridload = function(url, ids, fn) {\n  fn = fn || function(){};\n  var strids = ids.join(',');\n  supera\n  .get(url)\n  .query('postids=' + strids )\n  .end(function(res){\n    fn(res.text); \n   });\n};\n\n//@ sourceURL=main/request.js"
));
require.register("main/config.js", Function("exports, require, module",
"\n/**\n * Module dependencies\n */\n\nvar o = jQuery = require('jquery');\n\nvar envs = {\n  production: {\n    basedir: '',\n    async_url: '/wp-admin/admin-ajax.php'\n  },\n\n  stage: {\n    basedir: '/~cubhub',\n    async_url: '/~cubhub/wp-admin/admin-ajax.php'\n  },\n  \n  preprod: {\n    basedir: '/~cubscout',\n    async_url: '/~cubscout/wp-admin/admin-ajax.php'\n  },\n\n  development: {\n    basedir: '/cubhub',\n    async_url: '/cubhub/wp-admin/admin-ajax.php'\n  }\n}\n\n// detect current hostname\nvar host = o('body').data('server');\n\n/**\n * Export config module\n */\n\nmodule.exports = function (){\n  var env;\n\n  switch(host) {\n    case 'localhost':\n      env = 'development';\n      break;\n    case '67.222.18.91':\n      env = 'stage';\n      break;\n    case '209.236.115.170':\n      env = 'preprod';\n      break;\n\n    default:\n      env = 'production';\n  }\n\n  envs.env = env;\n\n  return envs[env];\n}\n//@ sourceURL=main/config.js"
));
require.alias("component-jquery/index.js", "main/deps/jquery/index.js");
require.alias("component-jquery/index.js", "jquery/index.js");

require.alias("visionmedia-debug/index.js", "main/deps/debug/index.js");
require.alias("visionmedia-debug/debug.js", "main/deps/debug/debug.js");
require.alias("visionmedia-debug/index.js", "debug/index.js");

require.alias("pinkTurtle-newslider/index.js", "main/deps/newslider/index.js");
require.alias("pinkTurtle-newslider/index.js", "newslider/index.js");
require.alias("component-emitter/index.js", "pinkTurtle-newslider/deps/emitter/index.js");

require.alias("component-jquery/index.js", "pinkTurtle-newslider/deps/jquery/index.js");

require.alias("component-inherit/index.js", "pinkTurtle-newslider/deps/inherit/index.js");

require.alias("visionmedia-debug/index.js", "pinkTurtle-newslider/deps/debug/index.js");
require.alias("visionmedia-debug/debug.js", "pinkTurtle-newslider/deps/debug/debug.js");

